eventlog

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Rendered for windows/amd64

Overview

Package eventlog provides a Logger that writes to Windows Event Log.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Writer

type Writer struct {
	// contains filtered or unexported fields
}

func NewEventLogWriter

func NewEventLogWriter(handle *eventlog.Log) *Writer

NewEventLogWriter returns a new Writer, which writes to Windows EventLog.

func (*Writer) Write

func (w *Writer) Write(p []byte) (int, error)

Jump to